'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _Table = require('./renderers/Table.component');

var _Table2 = _interopRequireDefault(_Table);

var _List = require('./renderers/List.component');

var _List2 = _interopRequireDefault(_List);

var _Large = require('./rowRenderers/Large.component');

var _Large2 = _interopRequireDefault(_Large);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var TABLE = 'TABLE';
var LARGE = 'LARGE';

function getRowRenderer(type) {
	switch (type) {
		case LARGE:
			return _Large2.default;
		default:
			throw new Error('Unknown row renderer in Virtualized List : ' + type);
	}
}

function RendererSelector(props) {
	var children = props.children,
	    collection = props.collection,
	    height = props.height,
	    sort = props.sort,
	    sortBy = props.sortBy,
	    sortDirection = props.sortDirection,
	    type = props.type,
	    width = props.width;

	if (type === TABLE) {
		return _react2.default.createElement(
			_Table2.default,
			{
				collection: collection,
				height: height,
				sort: sort,
				sortBy: sortBy,
				sortDirection: sortDirection,
				width: width
			},
			children
		);
	}
	return _react2.default.createElement(
		_List2.default,
		{
			collection: collection,
			height: height,
			width: width,
			rowRenderer: getRowRenderer(type)
		},
		children
	);
}
RendererSelector.propTypes = {
	children: _react.PropTypes.arrayOf(_react.PropTypes.element),
	collection: _react.PropTypes.arrayOf(_react.PropTypes.object),
	height: _react.PropTypes.number,
	sort: _react.PropTypes.func,
	sortBy: _react.PropTypes.string,
	sortDirection: _react.PropTypes.string,
	type: _react.PropTypes.oneOf([TABLE, LARGE]),
	width: _react.PropTypes.number
};
RendererSelector.defaultProps = {
	type: TABLE
};

exports.default = RendererSelector;